// This file is autogenerated by `scripts/generate-publishers.py`.
// Do not edit it by hand.
// Last updated at: 2025-08-24 13:59:51.650419+00:00

pub(crate) const KNOWN_PUBLISHERS: &[&str; 279] = &[
    "2D Market",
    "4th Dimension Entertainment",
    "801 Media",
    "Ablaze Publishing",
    "Abrams ComicArts",
    "ADV Manga",
    "Airship",
    "Akita Shoten (International)",
    "Alandal",
    "ALC Publishing",
    "Alien Books",
    "Alma Books",
    "Aloha Comics",
    "Alpha Manga",
    "Amimaru",
    "AMW Comics",
    "aNCHOR Inc",
    "Animate International",
    "Animate USA",
    "Antarctic Press",
    "Astral Rabbit Publishing",
    "Aurora Publishing",
    "Austin Macauley Publishers",
    "AYA Digital Comics",
    "Bamboo Press",
    "Bandai Entertainment",
    "Be Beautiful",
    "Bento Books",
    "BiliBili Comics",
    "BisouBisou Comics",
    "Black Hook Press",
    "Blaft Publications",
    "Blast Books",
    "BookLOUD",
    "Boom Manga",
    "Breakdown Press",
    "Broccoli",
    "Bruno Gmünder",
    "Bubbles Zine",
    "Burst Crisis",
    "Button Books",
    "Central Park Media",
    "Chereads",
    "Chuang Yi",
    "Comic Cat",
    "Comicle",
    "Comics One",
    "Comikey",
    "Concept Art House",
    "Concerned Theatre Japan",
    "Constable & Robinson",
    "Coolmic",
    "Copin Comics",
    "Cosmics Entertainment",
    "Creation Books",
    "Cross Infinite World",
    "Crossed Hearts",
    "Crunchyroll",
    "Dark Horse",
    "Dashtoon",
    "Day Comics",
    "Del Rey",
    "DeNA Manga Box",
    "DH Publishing",
    "Digital Manga",
    "Digital Manga Guild",
    "Dillyhub",
    "DokiDoki",
    "Doujins Unlimited",
    "Drama Queen",
    "Drawn & Quarterly",
    "Dreamspinner Press",
    "DrMaster",
    "Echo Communication",
    "Eclipse Comics",
    "Editio Publishing",
    "Educomics",
    "EigoMANGA",
    "Elex Technology Co. Ltd",
    "enjugroup",
    "Epic Comics",
    "Eros Comix",
    "FAKKU Books",
    "Fanboy Entertainment",
    "Fantagraphics",
    "First Comics",
    "Floating World Comics",
    "Flying Lines",
    "FuDeORS",
    "Full Moon",
    "Genesis Studio",
    "Glacier Bay Books",
    "Go! Comi",
    "GuiltPleasure",
    "Gumroad",
    "Gutsoon! Entertainment",
    "H&L Creative Studio Inc.",
    "Hanashi Media",
    "Harper Collins",
    "HicceArs",
    "HMarket",
    "Hollow Press",
    "HoneyToon",
    "Hotoon",
    "Hyper Comic",
    "Icarus Publishing",
    "Ice Kunion",
    "Idea Factory International",
    "IDW Publishing",
    "Image Comics",
    "Infinity Studios",
    "INKLORE",
    "INKR Comics",
    "Iris Print",
    "Irodori Comics",
    "Ishimori",
    "IZE Press",
    "J.U. Comics",
    "J18 Publishing",
    "JManga",
    "JR Comics",
    "K Manga",
    "Kadokawa BookWalker",
    "Kadokawa ComicWalker",
    "Kaiten Books",
    "Katharos Studios",
    "Kitty Media",
    "Knopf Doubleday",
    "Kodama Tales Inc.",
    "Kross Komics",
    "Lalatoon",
    "Landmark Books Pte.Ltd",
    "Last Gasp",
    "Les Humanoïdes Associés",
    "Lezhin US",
    "Lezhin X",
    "LILYKA",
    "LINE Webtoon",
    "Little, Brown Books",
    "Living the Line, LLC.",
    "Local Manga",
    "LoloBun",
    "Love Lab",
    "Magnetic Press",
    "Manga 18",
    "Manga Classics",
    "Manga Flip",
    "Manga Mavericks",
    "Manga Mirai",
    "Manga Planet",
    "MANGA Plus",
    "Manga Reborn",
    "Manga UP!",
    "MANGA.CLUB",
    "Mangamo",
    "MangaPlaza",
    "Mangatoon HK",
    "Manta Comics",
    "Marvel Comics",
    "Media Blasters",
    "Media Do",
    "MediBang ENG",
    "Midoraka Entertainment",
    "MiKandi Japan",
    "Mirage Studios",
    "MOJOIN (Eng)",
    "Monogatari Novels",
    "Mr. Blue ENG",
    "Mullebooks",
    "MyFutprint Entertainment, LLC",
    "Nakama Press",
    "NBM Publishing",
    "Net Comics",
    "Netmarble",
    "New Directions Publishing",
    "New York Review Books",
    "New York Review Comics",
    "Newsaura",
    "Nintendo Co., Ltd.",
    "No Starch Press",
    "Novelpia Global",
    "OmO Fictions",
    "One Peace Books",
    "Orange Inc.",
    "Otome's Way",
    "Oxford University Press",
    "Peach Flower House LLC",
    "Penguin Books",
    "PictureBox",
    "Pied Piper",
    "Planet Land Comics",
    "Pocket Comics",
    "Ponent Mon",
    "POP Comics",
    "Poppypub",
    "Project-H",
    "PUBLANG",
    "PUSH! Publications",
    "Pushkin Press",
    "Qidian International",
    "Radio Comix",
    "Radish",
    "Random House Graphic",
    "Redlight Manga",
    "Renta!",
    "Retrofit Comics",
    "Roll Inc.",
    "Rotten Blossoms",
    "Running Press",
    "Scholastic",
    "Sekai Project",
    "Serial Pleasures Publishing",
    "Shambhala",
    "Shogakukan Asia",
    "Short Books",
    "Shu Cream BL",
    "Shusuisha inc.",
    "Silent Manga Audition",
    "Silk Pagoda",
    "Smack Jeeves",
    "Sol Press",
    "SOZO Comics",
    "SpotToon",
    "Star Fruit Books",
    "Stone Bridge Press",
    "Strawberry Comics",
    "STREN CO.,LTD",
    "Studio Ekonte",
    "Studio Ironcat",
    "SuBLime",
    "Tanoshimi",
    "Tapas Media",
    "Tappytoon",
    "TapRead",
    "TCZ Studio ENGLISH",
    "Ten Speed Press",
    "Tentai Books",
    "The Beguiling",
    "The Yaoi Army",
    "Thoughts and Images",
    "Titan Comics",
    "Tokyo Otaku Mode",
    "TokyoPop",
    "Toodat Fiction",
    "Toonsutra",
    "Top Cow",
    "Top Shelf Productions",
    "Torycomics",
    "Toyspress",
    "Tuttle",
    "Tyndale House",
    "Ubisoft",
    "Udon Entertainment",
    "Ur Manga",
    "Vaibhavi Studios",
    "VAST Visual",
    "Vertical",
    "Via Lactea",
    "Volare Novels",
    "Wattpad",
    "Webcomics",
    "Webtoon Factory (EN)",
    "WeComics",
    "Winged Cloud",
    "Wiz Corporation",
    "WordExcerpt",
    "Wutopia",
    "Wuxiaworld",
    "XSEED Games",
    "Yaoi Generation",
    "Yaoi Press",
    "Yaoi Revolution",
    "YaoiCat",
    "YaoiFix",
    "Yen On",
    "yomoyo",
    "Yonder",
    "Yoru Studios",
    "YURI HUB",
];
